==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/29/290730d7fec9846154f10ebb7fce0a6e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Validator/EntityEventValidator.php */
class __TwigTemplate_63000fa2f96ee8d2dd2d51c972aa98f5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Validator;

use Mautic\\CoreBundle\\Event\\EntityValidateEvent;
use Symfony\\Component\\Validator\\Constraint;
use Symfony\\Component\\Validator\\ConstraintValidator;
use Symfony\\Component\\Validator\\Exception\\UnexpectedTypeException;
use Symfony\\Contracts\\EventDispatcher\\EventDispatcherInterface;

final class EntityEventValidator extends ConstraintValidator
{
    public function __construct(private EventDispatcherInterface \$dispatcher)
    {
    }

    public function validate(\$value, Constraint \$constraint): void
    {
        if (!is_object(\$value)) {
            throw new UnexpectedTypeException(\$value, 'object');
        }

        if (!\$constraint instanceof EntityEvent) {
            throw new UnexpectedTypeException(\$constraint, EntityEvent::class);
        }

        \$this->dispatcher->dispatch(new EntityValidateEvent(\$value, \$constraint, \$this->context));
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Validator/EntityEventValidator.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Validator/EntityEventValidator.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Validator/EntityEventValidator.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/29/290730d7fec9846154f10ebb7fce0a6e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Validator/EntityEventValidator.php */
class __TwigTemplate_63000fa2f96ee8d2dd2d51c972aa98f5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Validator;

use Mautic\\CoreBundle\\Event\\EntityValidateEvent;
use Symfony\\Component\\Validator\\Constraint;
use Symfony\\Component\\Validator\\ConstraintValidator;
use Symfony\\Component\\Validator\\Exception\\UnexpectedTypeException;
use Symfony\\Contracts\\EventDispatcher\\EventDispatcherInterface;

final class EntityEventValidator extends ConstraintValidator
{
    public function __construct(private EventDispatcherInterface \$dispatcher)
    {
    }

    public function validate(\$value, Constraint \$constraint): void
    {
        if (!is_object(\$value)) {
            throw new UnexpectedTypeException(\$value, 'object');
        }

        if (!\$constraint instanceof EntityEvent) {
            throw new UnexpectedTypeException(\$constraint, EntityEvent::class);
        }

        \$this->dispatcher->dispatch(new EntityValidateEvent(\$value, \$constraint, \$this->context));
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Validator/EntityEventValidator.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Validator/EntityEventValidator.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Validator/EntityEventValidator.php");
    }
}
